'use strict';

import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { View } from 'react-native';
import User from '@services/User';
import { Events, Config, Languages } from '@common';

import { ROUTER } from '../../Navigation/constants';

export default class Base extends PureComponent {
  static propTypes = {
    goToScreen: PropTypes.func,
  };

  constructor(props) {
    super(props);
    this.state = { userData: '' };
    this.fetchDataUser();
    Events.onSideMenuRefresh(this.fetchDataUser);

    this.items = [
      {
        label: Languages.news,
        icon: 'home',
        onPress: () => this.goToScreen(ROUTER.NEWS_STACK),
      },
      { label: Languages.contact, icon: 'mail', onPress: this.goToContact },
      { label: Languages.aboutus, icon: 'assignment', onPress: this.goToAbout },
      {
        label: Languages.setting,
        icon: 'settings',
        onPress: () => this.goToScreen(ROUTER.SETTING_SCREEN),
      },
      {
        label: Languages.user,
        icon: 'User',
        onPress: () => {
          this.goToScreen(ROUTER.READ_LATER_SCREEN);
          Events.openUserModal();
        },
      },
    ];
  }

  fetchDataUser = () => {
    const self = this;
    User.getUser().then(data => {
      self.setState({
        userData: data,
      });
    });
  };

  goToContact = () => {
    this.goToScreen(ROUTER.CUSTOM_PAGE_SCREEN, {
      id: Config.CustomPages.contact_id,
      title: Languages.contact,
    });
  };

  goToAbout = () => {
    this.goToScreen(ROUTER.CUSTOM_PAGE_SCREEN, {
      id: Config.CustomPages.aboutus_id,
      title: Languages.aboutus,
    });
    // you can also use custom page by using
    // this.goToScreen(ROUTER.CUSTOM_PAGE_SCREEN, {url: 'http://inspireui.com'});
  };

  goToScreen = (routeName, params = {}) => {
    this.props.goToScreen(routeName, params, false);
    Events.closeLeftMenu();
  };

  logout = () => {
    Events.logoutUser();
    this.setState({ userData: undefined });
    Events.closeLeftMenu();
  };

  login() {
    // Actions.login();
  }

  render() {
    return <View />;
  }
}
