/** @format */

import React, { Component } from 'react';
import { View, Platform, StatusBar, I18nManager } from 'react-native';
import { NavigationContainer } from '@react-navigation/native';
import { connect } from 'react-redux';

import { Events, Style, Constants, Config, Device } from '@common';
import MenuScale from '@components/LeftMenu/MenuScale';
import MenuOverlay from '@components/LeftMenu/MenuOverlay';
import MenuSmall from '@components/LeftMenu/MenuSmall';
import MenuWide from '@components/LeftMenu/MenuWide';
import MenuAndroid from '@components/LeftMenu/MenuAndroid';
import MainNavigator, { navigationRef } from './Navigation';

class RootRouter extends Component {
  constructor(props) {
    super(props);
    this.state = { menuStyle: 0 };

    !Device.isIphoneX && StatusBar.setHidden(true);
    I18nManager.forceRTL(Constants.RTL);
    // Set Default Language for App
    // Languages.setLanguage(Config.Language);
  }

  changeMenuStyle(data) {
    this.setState({ menuStyle: data.menuId });
  }

  componentDidMount() {
    Events.appChangeMenuStyle(this.changeMenuStyle.bind(this));
    let { isLoggedIn } = this.props;
    if (!isLoggedIn && Config.RequiredLogin) {
      Events.openUserModal();
    }
  }

  goToScreen = (routeName, params, isReset = true) => {
    console.log(
      '🚀🚀🚀Luyx🚀🚀🚀 ~ file: RootRouter.js ~ line 40 ~ RootRouter ~ routeName',
      routeName,
    );
    // fix the navigation for Custom page
    if (routeName) {
      navigationRef?.current?.navigate(routeName, params);
    }
  };

  renderContent = () => {
    let { isLoggedIn } = this.props;
    return (
      <View style={Style.app}>
        {Device.isIphoneX && (
          <StatusBar backgroundColor="white" barStyle="dark-content" />
        )}
        {(isLoggedIn || !Config.RequiredLogin) && (
          <NavigationContainer ref={navigationRef}>
            <MainNavigator />
          </NavigationContainer>
        )}
      </View>
    );
  };

  render() {
    const { small, wide, overlay } = Constants.LeftMenu;

    if (Platform.OS === 'android') {
      return (
        <MenuAndroid
          goToScreen={this.goToScreen}
          routes={this.renderContent()}
        />
      );
    }

    switch (Config.LeftMenuStyle) {
      case small:
        return (
          <MenuSmall
            goToScreen={this.goToScreen}
            routes={this.renderContent()}
          />
        );
      case wide:
        return (
          <MenuWide
            goToScreen={this.goToScreen}
            routes={this.renderContent()}
          />
        );
      case overlay:
        return (
          <MenuOverlay
            goToScreen={this.goToScreen}
            routes={this.renderContent()}
          />
        );
      default:
        return (
          <MenuScale
            goToScreen={this.goToScreen}
            routes={this.renderContent()}
          />
        );
    }
  }
}

const mapStateToProps = ({ user, bookmark }) => {
  return {
    isLoggedIn: user && user.data,
  };
};
export default connect(mapStateToProps, {})(RootRouter);
